@@ -50,9 +50,6 @@
 #' sample_points <- matrix(c(10, 5, 25, 15, 5, 25), ncol = 2, byrow = TRUE)
 #' sample_lsm(landscape, y = sample_points, size = 15, what = "lsm_l_np")
 #'
-#' @aliases sample_lsm
-#' @rdname sample_lsm
-#'
 #' @export
 sample_lsm <- function(landscape, y, plot_id = NULL, shape = "square", size = NULL,
                        all_classes = FALSE, return_raster = FALSE,
@@ -111,12 +108,15 @@ sample_lsm_int <- function(landscape, y, plot_id, shape, size,
         # convert to terra
         y <- methods::as(y, "SpatVector")
 
+        # get crs
+        crs <- terra::crs(y)
+
         if (terra::geomtype(y) == "points") {
 
             if (is.null(size) | size == 0) stop("Please provide size argument size > 0.", call. = FALSE)
 
             y <- construct_buffer(coords = y, shape = shape, size = size,
-                                  return_vec = TRUE, verbose = verbose)
+                                  return_vec = TRUE, crs = crs, verbose = verbose)
 
         }
 
